/*
 * Receive XBee packets in API mode with xbee-api
 * XBee#2 send values from an analog sensor to XBee#1
 *
 * From http://code.google.com/p/xbee-api/wiki/Processing
 * Download xbee-api : http://code.google.com/p/xbee-api/
 *
 * Configurations : 
 * XBEE#1 receiver : ATRE, ATID1111, ATMY1111, ATDL0, ADH0, ATAP2, ATWR
 * XBEE#2 sender   : ATRE, ATID1111, ATMY2222, ATDL1111, ADH0, ATAP2, ATD02, ATIR64, ATIT1, ATIU1, ATWR
 * XBEE#3 sender   : ATRE, ATID1111, ATMY3333, ATDL1111, ADH0, ATAP2, ATD02, ATIR64, ATIT1, ATIU1, ATWR
 */

import processing.serial.*;
import java.util.concurrent.*;
import java.util.Queue; //  avoid Queue error

XBee xbee;
Queue<XBeeResponse> queue = new ConcurrentLinkedQueue<XBeeResponse>();
boolean message;
XBeeResponse response;

void setup() {
  try { 
   // PropertyConfigurator.configure(dataPath("")+"/log4j.properties"); // optional. set up logging
    xbee = new XBee();
    xbee.open("/dev/ttyUSB0", 9600); // replace with your COM port
    xbee.addPacketListener(new PacketListener() {
      public void processResponse(XBeeResponse response) {
        queue.offer(response);
      }
    }
    );
  } 
  catch (Exception e) {
    System.out.println("XBee failed to initialize");
    e.printStackTrace();
    System.exit(1);
  }
}

void draw() {
  try { 
    readPackets();
  } 
  catch (Exception e) {
    e.printStackTrace();
  }
}

void readPackets() throws Exception {
  while ((response = queue.poll()) != null) {
    // we got something!
    try {
      RxResponseIoSample ioSample = (RxResponseIoSample) response;
      println("Sample from " + ioSample.getSourceAddress()); // address
      if (ioSample.containsAnalog()) {
        println(ioSample.getSamples()[0].getAnalog0()); // 10 bits
      }
    } 
    catch (ClassCastException e) {
      // not an IO Sample
    }
  }
}
